@@ -50,7 +50,7 @@ class ClientManager(object):
 
             if is_logged_in:
                 log.info(_("Successfully added server."))
-                add_another = input(_("Add another server? [y/N] "))
+                add_another = input(_("Add another server?") + " [y/N] ")
                 add_another = add_another in ("y", "Y", "yes", "Yes")
             else:
                 log.warning(_("Adding server failed."))
@@ -60,9 +60,16 @@ class ClientManager(object):
         client.config.data['app.default'] = True
         client.config.app(USER_APP_NAME, CLIENT_VERSION, settings.player_name, settings.client_uuid)
         client.config.data['http.user_agent'] = USER_AGENT
-        client.config.data['auth.ssl'] = True
+        client.config.data['auth.ssl'] = not settings.ignore_ssl_cert
         return client
 
+    def _connect_all(self):
+        is_logged_in = False
+        for server in self.credentials:
+            if self._connect_client(server):
+                is_logged_in = True
+        return is_logged_in
+
     def try_connect(self):
         credentials_location = conffile.get(APP_NAME,'cred.json')            
         if os.path.exists(credentials_location):
@@ -77,10 +84,15 @@ class ClientManager(object):
                 server["username"] = ""
                 self.credentials.append(server)
 
-        is_logged_in = False
-        for server in self.credentials:
-            if self._connect_client(server):
-                is_logged_in = True
+        is_logged_in = self._connect_all()
+        if settings.connect_retry_mins and not is_logged_in:
+            log.warning("Connection failed. Will retry for {0} minutes."
+                        .format(settings.connect_retry_mins))
+            for attempt in range(settings.connect_retry_mins * 2):
+                time.sleep(30)
+                is_logged_in = self._connect_all()
+                if is_logged_in:
+                    break
 
         return is_logged_in
 
@@ -105,10 +117,8 @@ class ClientManager(object):
 
         client = self.client_factory()
         client.auth.connect_to_address(server)
-        client.auth.login(server, username, password)
-        state = client.auth.connect()
-        is_logged_in = state['State'] == CONNECTION_STATE['SignedIn']
-        if is_logged_in:
+        result = client.auth.login(server, username, password)
+        if "AccessToken" in result:
             credentials = client.auth.credentials.get_credentials()
             server = credentials["Servers"][0]
             if force_unique:
@@ -121,8 +131,8 @@ class ClientManager(object):
             self._connect_client(server)
             self.credentials.append(server)
             self.save_credentials()
-
-        return is_logged_in
+            return True
+        return False
 
     def setup_client(self, client, server):
         def event(event_name, data):
