@@ -40,6 +40,7 @@ class Settings(object):
         "mpv_ext_path":         None,
         "mpv_ext_ipc":          None,
         "mpv_ext_start":        True,
+        "mpv_ext_no_ovr":       False,
         "enable_osc":           True,
         "use_web_seek":         False,
         "display_mirroring":    False,
@@ -47,7 +48,8 @@ class Settings(object):
         "mpv_log_level":        "info",
         "enable_desktop":       False,
         "desktop_fullscreen":   False,
-        "desktop_remember_pos": True,
+        "desktop_keep_pos":     False,
+        "desktop_keep_size":    True,
         "idle_when_paused":     False,
         "stop_idle":            False,
         "transcode_to_h265":    False,
@@ -64,6 +66,7 @@ class Settings(object):
         "kb_menu_up":           "up",
         "kb_menu_down":         "down",
         "kb_pause":             "space",
+        "kb_fullscreen":        "f",
         "kb_debug":             "~",
         "seek_up":              60,
         "seek_down":            -60,
@@ -92,6 +95,12 @@ class Settings(object):
         "notify_updates":       True,
         "lang":                 None,
         "desktop_scale":        1.0,
+        "discord_presence":     False,
+        "ignore_ssl_cert":      False,
+        "menu_mouse":           True,
+        "media_keys":           True,
+        "connect_retry_mins":   0,
+        "transcode_warning":    True,
     }
 
     def __getattr__(self, name):
