@@ -8,6 +8,7 @@ from sys import platform
 
 from .conf import settings
 from .utils import is_local_domain, get_profile, get_seq
+from .i18n import _
 
 log = logging.getLogger('media')
 
@@ -101,7 +102,7 @@ class Video(object):
                 if year is not None:
                     title = "%s (%s)" % (title, year)
             setattr(self, "_title", title)
-        return getattr(self, "_title") + (" (Transcode)" if self.is_transcode else "")
+        return getattr(self, "_title") + (_(" (Transcode)") if self.is_transcode else "")
 
     def set_trs_override(self, video_bitrate, force_transcode):
         if force_transcode:
@@ -134,18 +135,21 @@ class Video(object):
         # - If there's a scheme specified or the path exists as a local file.
         if ((self.media_source.get('Protocol') == "Http" or self.media_source['SupportsDirectPlay'])
             and settings.direct_paths and (settings.remote_direct_paths or self.parent.is_local)):
+
+            if platform.startswith("win32") or platform.startswith("cygwin"):
+                    # matches on SMB scheme
+                    match = re.search('(?:\\\\).+:.*@(.+)', self.media_source['Path'])
+                    if match:
+                        # replace forward slash to backward slashes
+                        log.debug("cleaned up credentials from path")
+                        self.media_source['Path'] = str(pathlib.Path('\\\\' + match.groups()[0]))
+
             if urllib.parse.urlparse(self.media_source['Path']).scheme:
                 self.is_transcode = False
                 log.debug("Using remote direct path.")
                 # translate path for windows 
                 # if path is smb path in credential format for kodi and maybe linux \\username:password@mediaserver\foo, 
                 # translate it to mediaserver/foo 
-                if sys.platform.startswith("win32") or sys.platform.startswith("cygwin"):
-                    # matches on SMB scheme
-                    match = re.search('(?:\\\\).+:.*@(.+)', self.media_source['Path'])
-                    if match:
-                        # replace forward slash to backward slashes
-                        return pathlib.Path('\\\\' + match.groups()[0])
                 return pathlib.Path(self.media_source['Path'])
             else:
                 # If there's no uri scheme, check if the file exixsts because it might not be mounted
@@ -279,9 +283,9 @@ class Media(object):
             return self.video
         
         if index < len(self.queue):
-            return Video(queue[index]["Id"], self)
+            return Video(self.queue[index]["Id"], self)
 
-        log.error("Media::get_video couldn't find video at index %s" % video)
+        log.error("Media::get_video couldn't find video at index %s" % index)
     
     def insert_items(self, items, append=False):
         items = [{ "PlaylistItemId": "playlistItem{0}".format(get_seq()), "Id": id_num } for id_num in items]
