@@ -1,4 +1,4 @@
-from queue import Queue, LifoQueue
+from queue import LifoQueue
 from .bulk_subtitle import process_series
 from .conf import settings
 from .utils import mpv_color_to_plex, get_sub_display_title
@@ -56,6 +56,7 @@ class OSDMenu(object):
         self.menu_list = []
         self.menu_selection = 0
         self.menu_tmp = None
+        self.mouse_back = False
         self.original_osd_color = playerManager._player.osd_back_color
         self.original_osd_size = playerManager._player.osd_font_size
 
@@ -84,15 +85,28 @@ class OSDMenu(object):
         items = self.menu_list
         selected_item = self.menu_selection
 
-        menu_text = "{0}".format(self.menu_title)
+        if self.mouse_back:
+            menu_text = "(<--) {0}".format(self.menu_title)
+        else:
+            menu_text = self.menu_title
         for i, item in enumerate(items):
             fmt = "\n   {0}"
-            if i == selected_item:
+            if i == selected_item and not self.mouse_back:
                 fmt = "\n   **{0}**"
             menu_text += fmt.format(item[0])
 
         self.playerManager._player.show_text(menu_text, 2**30, 1)
 
+    def mouse_select(self, idx):
+        if idx < 0 or idx > len(self.menu_list):
+            return
+        if idx == 0:
+            self.mouse_back = True
+        else:
+            self.mouse_back = False
+            self.menu_selection = idx - 1
+        self.refresh_menu()
+
     def show_menu(self):
         self.is_menu_shown = True
         player = self.playerManager._player
@@ -101,9 +115,12 @@ class OSDMenu(object):
 
         if hasattr(player, 'osc'):
             player.osc = False
-        
+
+        player.command("script-message", "shim-menu-enable", "True")
+
         self.menu_title = _("Main Menu")
         self.menu_selection = 0
+        self.mouse_back = False
 
         if self.playerManager._video and not player.playback_abort:
             self.menu_list = [
@@ -133,7 +150,8 @@ class OSDMenu(object):
             self.menu_list.append((_("SVP Settings"), self.svp_menu.menu_action))
 
         self.menu_list.extend([
-            (_("Preferences"), self.preferences_menu),
+            (_("Video Preferences"), self.video_preferences_menu),
+            (_("Player Preferences"), self.player_preferences_menu),
             (_("Close Menu"), self.hide_menu)
         ])
 
@@ -164,6 +182,8 @@ class OSDMenu(object):
             if hasattr(player, 'osc'):
                 player.osc = settings.enable_osc
 
+            player.command("script-message", "shim-menu-enable", "False")
+
             if player.playback_abort:
                 player.play("")
             else:
@@ -201,9 +221,13 @@ class OSDMenu(object):
                 else:
                     self.menu_title, self.menu_list, self.menu_selection = self.menu_stack.get_nowait()
             elif action == "ok":
-                self.menu_list[self.menu_selection][1]()
+                if self.mouse_back:
+                    self.menu_action("back")
+                else:
+                    self.menu_list[self.menu_selection][1]()
             elif action == "home":
                 self.show_menu()
+            self.mouse_back = False
             self.refresh_menu()
 
     def change_audio_menu_handle(self):
@@ -328,11 +352,12 @@ class OSDMenu(object):
         # Need to re-render preferences menu.
         for i in range(2):
             self.menu_action("back")
-        self.preferences_menu()
+        self.video_preferences_menu()
 
     def transcode_settings_menu(self):
         self.put_menu(_("Select Default Transcode Profile"))
         handle = self.transcode_settings_handle
+        self.menu_list.append((_("No Transcode") + " 2 Gbps", handle, 2147483))
 
         for i, item in enumerate(TRANSCODE_LEVELS):
             self.menu_list.append((item[0], handle, item[1]))
@@ -354,7 +379,7 @@ class OSDMenu(object):
         # Need to re-render preferences menu.
         for i in range(2):
             self.menu_action("back")
-        self.preferences_menu()
+        self.video_preferences_menu()
 
         if self.playerManager._video.is_transcode:
             if setting_name == "subtitle_size":
@@ -381,9 +406,8 @@ class OSDMenu(object):
             (_("Middle"), self.sub_settings_handle, "subtitle_position", "middle"),
         ])
 
-    def preferences_menu(self):
-        self.put_menu(_("Preferences"), [
-            self.get_settings_toggle(_("Auto Play"), "auto_play"),
+    def video_preferences_menu(self):
+        self.put_menu(_("Video Preferences"), [
             (_("Remote Transcode Quality: {0:0.1f} Mbps").format(settings.remote_kbps/1000), self.transcode_settings_menu),
             (_("Subtitle Size: {0}").format(settings.subtitle_size), self.subtitle_size_menu),
             (_("Subtitle Position: {0}").format(settings.subtitle_position), self.subtitle_position_menu),
@@ -391,14 +415,20 @@ class OSDMenu(object):
             self.get_settings_toggle(_("Transcode H265 to H264"), "transcode_h265"),
             self.get_settings_toggle(_("Transcode Hi10p to 8bit"), "transcode_hi10p"),
             self.get_settings_toggle(_("Direct Paths"), "direct_paths"),
+            self.get_settings_toggle(_("Transcode to H265"), "transcode_to_h265"),
+            self.get_settings_toggle(_("Disable Direct Play"), "always_transcode"),
+        ])
+
+    def player_preferences_menu(self):
+        self.put_menu(_("Player Preferences"), [
+            self.get_settings_toggle(_("Auto Play"), "auto_play"),
             self.get_settings_toggle(_("Auto Fullscreen"), "fullscreen"),
             self.get_settings_toggle(_("Media Key Seek"), "media_key_seek"),
             self.get_settings_toggle(_("Use Web Seek Pref"), "use_web_seek"),
             self.get_settings_toggle(_("Display Mirroring"), "display_mirroring"),
-            self.get_settings_toggle(_("Transcode to H265"), "transcode_to_h265"),
             self.get_settings_toggle(_("Write Logs to File"), "write_logs"),
-            self.get_settings_toggle(_("Disable Direct Play"), "always_transcode"),
             self.get_settings_toggle(_("Check for Updates"), "check_updates"),
+            self.get_settings_toggle(_("Discord Rich Presence"), "discord_presence"),
         ])
 
     def unwatched_menu_handle(self):
