@@ -6,18 +6,29 @@ import time
 
 from threading import RLock, Lock, Event
 from queue import Queue
+from collections import OrderedDict
 
 from . import conffile
-from .utils import synchronous, Timer, none_fallback
+from .utils import synchronous, Timer, none_fallback, get_resource
 from .conf import settings
 from .menu import OSDMenu
 from .constants import APP_NAME
 from .syncplay import SyncPlayManager
 from .update_check import UpdateChecker
+from .i18n import _
 
 log = logging.getLogger('player')
 mpv_log = logging.getLogger('mpv')
 
+
+discord_presence = False
+if settings.discord_presence:
+    try:
+        from .rich_presence import send_presence, clear_presence
+        discord_presence = True
+    except Exception:
+        log.error("Could not enable Discord Rich Presence.", exc_info=True)
+
 python_mpv_available=True
 is_using_ext_mpv=False
 if not settings.mpv_ext:
@@ -98,10 +109,8 @@ class PlayerManager(object):
     violates assumptions.
     """
     def __init__(self):
-        mpv_config = conffile.get(APP_NAME,"mpv.conf", True)
-        input_config = conffile.get(APP_NAME,"input.conf", True)
         self._video = None
-        extra_options = {}
+        mpv_options = OrderedDict()
         self.timeline_trigger = None
         self.action_trigger = None
         self.external_subtitles = {}
@@ -118,19 +127,28 @@ class PlayerManager(object):
         self.get_webview = lambda: None
         self.pause_ignore = None  # Used to ignore pause events that come from us.
         self.last_seek = None
+        self.warned_about_transcode = False
+        self.fullscreen_disable = False
         self.update_check = UpdateChecker(self)
 
         if is_using_ext_mpv:
-            extra_options = {
+            mpv_options.update({
                 "start_mpv": settings.mpv_ext_start,
                 "ipc_socket": settings.mpv_ext_ipc,
                 "mpv_location": settings.mpv_ext_path,
                 "player-operation-mode": "cplayer"
-            }
+            })
+        if settings.menu_mouse:
+            if is_using_ext_mpv:
+                mpv_options["script"] = get_resource("mouse.lua")
+            else:
+                mpv_options["scripts"] = get_resource("mouse.lua")
+        if not (settings.mpv_ext and settings.mpv_ext_no_ovr):
+            mpv_options["include"] = conffile.get(APP_NAME, "mpv.conf", True)
+            mpv_options["input_conf"] = conffile.get(APP_NAME, "input.conf", True)
         self._player = mpv.MPV(input_default_bindings=True, input_vo_keyboard=True,
-                               input_media_keys=True, include=mpv_config, input_conf=input_config,
-                               log_handler=mpv_log_handler, loglevel=settings.mpv_log_level,
-                               **extra_options)
+                               input_media_keys=settings.media_keys, log_handler=mpv_log_handler,
+                               loglevel=settings.mpv_log_level, **mpv_options)
         self.menu = OSDMenu(self)
         self.syncplay = SyncPlayManager(self)
 
@@ -200,6 +218,7 @@ class PlayerManager(object):
                 self.menu.menu_action('back')
             else:
                 self._player.command('set', 'fullscreen', 'no')
+                self.fullscreen_disable = True
 
         @keypress(settings.kb_menu_ok)
         def menu_ok():
@@ -246,6 +265,10 @@ class PlayerManager(object):
             else:    
                 self.toggle_pause()
 
+        @keypress(settings.kb_fullscreen)
+        def handle_fullscreen():
+            self.toggle_fullscreen()
+
         # This gives you an interactive python debugger prompt.
         @keypress(settings.kb_debug)
         def handle_debug():
@@ -296,6 +319,22 @@ class PlayerManager(object):
                         self.syncplay.play_request()
                         self.set_paused(True, True)
 
+        @self._player.event_callback('client-message')
+        def handle_client_message(event):
+            try:
+                if "event_id" in event:
+                    args = event["event"]["args"]
+                else:
+                    args = event["args"]
+                if len(args) == 0:
+                    return
+                if args[0] == "shim-menu-select":
+                    self.menu.mouse_select(int(args[1]))
+                elif args[0] == "shim-menu-click":
+                    self.menu.menu_action("ok")
+            except Exception:
+                log.warning("Error when processing client-message.", exc_info=True)
+
     # Put a task to the event queue.
     # This ensures the task executes outside
     # of an event handler, which causes a crash.
@@ -347,7 +386,7 @@ class PlayerManager(object):
             self.stop()
             return
         log.debug("Finished waiting for media duration.")
-        if settings.fullscreen:
+        if settings.fullscreen and not self.fullscreen_disable:
             self._player.fs = True
         self._player.force_media_title = video.get_proper_title()
         self._video = video
@@ -374,6 +413,14 @@ class PlayerManager(object):
 
         self.update_check.check()
 
+        if (not self._video.parent.is_local and self._video.is_transcode
+            and not self.warned_about_transcode and settings.transcode_warning):
+            self.warned_about_transcode = True
+            self._player.show_text(
+                _("Your remote video is transcoding!\nPress c to adjust bandwidth settings if this is not needed."),
+                5000, 1
+            )
+
     def exec_stop_cmd(self):
         if settings.stop_cmd:
             os.system(settings.stop_cmd)
@@ -589,6 +636,7 @@ class PlayerManager(object):
     @synchronous('_lock')
     def toggle_fullscreen(self):
         self._player.fs = not self._player.fs
+        self.fullscreen_disable = not self._player.fs
 
     @synchronous('_lock')
     def set_mute(self, mute):
@@ -649,6 +697,21 @@ class PlayerManager(object):
                 "start": int(safe_pos * 10000000),
                 "end": int(((player.duration - safe_pos * none_fallback(player.cache_buffering_state, 0) / 100) + safe_pos) * 10000000)
             }]
+        if discord_presence:
+            try:
+                if (self._video.is_tv and self._video.item.get("IndexNumber") is not None
+                        and self._video.item.get("ParentIndexNumber") is not None):
+                    title = self._video.item.get("SeriesName")
+                    subtitle = _("Season {0} - Episode {1}").format(
+                        self._video.item.get("ParentIndexNumber"),
+                        self._video.item.get("IndexNumber")
+                    )
+                else:
+                    title = self._video.item.get("Name")
+                    subtitle = str(self._video.item.get("ProductionYear", ""))
+                send_presence(title, subtitle, player.playback_time, player.duration, not player.pause)
+            except Exception:
+                log.error("Could not send Discord Rich Presence.", exc_info=True)
         return options
 
     @synchronous('_tl_lock')
@@ -671,6 +734,12 @@ class PlayerManager(object):
             (settings.display_mirroring or settings.desktop_fullscreen)):
             self.get_webview().show()
 
+        if discord_presence:
+            try:
+                clear_presence()
+            except Exception:
+                log.error("Could not clear Discord Rich Presence.", exc_info=True)
+
     def upd_player_hide(self):
         self._player.keep_open = self._video.parent.has_next
 
