@@ -151,9 +151,21 @@ class WebviewClient(object):
         self.server.start()
 
         extra_options = {}
-        if os.path.exists(remember_layout) and settings.desktop_remember_pos:
+        if os.path.exists(remember_layout):
             with open(remember_layout) as fh:
-                extra_options = json.load(fh)
+                layout_options = json.load(fh)
+            if settings.desktop_keep_pos and layout_options.get("x") and layout_options.get("y"):
+                extra_options["x"] = layout_options["x"]
+                extra_options["y"] = layout_options["y"]
+            if settings.desktop_keep_size and layout_options.get("width") and layout_options.get("height"):
+                extra_options["width"] = layout_options["width"]
+                extra_options["height"] = layout_options["height"]
+        else:
+            # Set a reasonable window size
+            extra_options.update({
+                "width": 1280,
+                "height": 720
+            })
         if not self.cef and sys.platform.startswith("win32") or sys.platform.startswith("cygwin"):
             # I wasted half a day here. Turns out that pywebview does something that
             # breaks Jellyfin on Windows in both EdgeHTML and CEF. This kills that.
